<a id="mypy-boto3-devops-guru"></a>

# mypy-boto3-devops-guru

[![PyPI - types-aiobotocore-devops-guru](https://img.shields.io/pypi/v/types-aiobotocore-devops-guru.svg?color=blue)](https://pypi.org/project/types-aiobotocore-devops-guru)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-devops-guru.svg?color=blue)](https://pypi.org/project/types-aiobotocore-devops-guru)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-devops-guru?color=blue)](https://pypistats.org/packages/types-aiobotocore-devops-guru)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.DevOpsGuru 1.20.47](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.4.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[types-aiobotocore-devops-guru docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_devops_guru/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-devops-guru](#mypy-boto3-devops-guru)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `DevOpsGuru`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `DevOpsGuru` service.

```bash
python -m pip install types-aiobotocore[devops-guru]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[devops-guru]` in your environment:
  `python -m pip install 'types-aiobotocore[devops-guru]'`

Both type checking and auto-complete should work for `DevOpsGuru` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `types-aiobotocore[devops-guru]` in your environment:
  `python -m pip install 'types-aiobotocore[devops-guru]'`

Both type checking and auto-complete should work for `DevOpsGuru` service. No
explicit type annotations required, write your `aiobotocore` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`types-aiobotocore` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[devops-guru]` in your environment:
  `python -m pip install 'types-aiobotocore[devops-guru]'`
- Run `mypy` as usual

Type checking should work for `DevOpsGuru` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `types-aiobotocore[devops-guru]` in your environment:
  `python -m pip install 'types-aiobotocore[devops-guru]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `DevOpsGuru` service. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`DevOpsGuruClient` provides annotations for
`session.create_client("devops-guru")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_devops_guru import DevOpsGuruClient

session = get_session()
with async session.create_client("devops-guru") as client:
    client: DevOpsGuruClient
    # now client usage is checked by mypy and IDE should provide code auto-complete
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_devops_guru.paginator` module contains type annotations for
all paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_devops_guru import DevOpsGuruClient
from types_aiobotocore_devops_guru.paginator import (
    DescribeOrganizationResourceCollectionHealthPaginator,
    DescribeResourceCollectionHealthPaginator,
    GetCostEstimationPaginator,
    GetResourceCollectionPaginator,
    ListAnomaliesForInsightPaginator,
    ListEventsPaginator,
    ListInsightsPaginator,
    ListNotificationChannelsPaginator,
    ListOrganizationInsightsPaginator,
    ListRecommendationsPaginator,
    SearchInsightsPaginator,
    SearchOrganizationInsightsPaginator,
)

session = get_session()
with async session.create_client("devops-guru") as client:
    client: DevOpsGuruClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        describe_organization_resource_collection_health_paginator: DescribeOrganizationResourceCollectionHealthPaginator = client.get_paginator("describe_organization_resource_collection_health")
        describe_resource_collection_health_paginator: DescribeResourceCollectionHealthPaginator = client.get_paginator("describe_resource_collection_health")
        get_cost_estimation_paginator: GetCostEstimationPaginator = client.get_paginator("get_cost_estimation")
        get_resource_collection_paginator: GetResourceCollectionPaginator = client.get_paginator("get_resource_collection")
        list_anomalies_for_insight_paginator: ListAnomaliesForInsightPaginator = client.get_paginator("list_anomalies_for_insight")
        list_events_paginator: ListEventsPaginator = client.get_paginator("list_events")
        list_insights_paginator: ListInsightsPaginator = client.get_paginator("list_insights")
        list_notification_channels_paginator: ListNotificationChannelsPaginator = client.get_paginator("list_notification_channels")
        list_organization_insights_paginator: ListOrganizationInsightsPaginator = client.get_paginator("list_organization_insights")
        list_recommendations_paginator: ListRecommendationsPaginator = client.get_paginator("list_recommendations")
        search_insights_paginator: SearchInsightsPaginator = client.get_paginator("search_insights")
        search_organization_insights_paginator: SearchOrganizationInsightsPaginator = client.get_paginator("search_organization_insights")
    ```







### Literals

`types_aiobotocore_devops_guru.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_devops_guru.literals import (
    AnomalySeverityType,
    AnomalyStatusType,
    AnomalyTypeType,
    CloudWatchMetricDataStatusCodeType,
    CloudWatchMetricsStatType,
    CostEstimationServiceResourceStateType,
    CostEstimationStatusType,
    DescribeOrganizationResourceCollectionHealthPaginatorName,
    DescribeResourceCollectionHealthPaginatorName,
    EventClassType,
    EventDataSourceType,
    GetCostEstimationPaginatorName,
    GetResourceCollectionPaginatorName,
    InsightFeedbackOptionType,
    InsightSeverityType,
    InsightStatusType,
    InsightTypeType,
    ListAnomaliesForInsightPaginatorName,
    ListEventsPaginatorName,
    ListInsightsPaginatorName,
    ListNotificationChannelsPaginatorName,
    ListOrganizationInsightsPaginatorName,
    ListRecommendationsPaginatorName,
    LocaleType,
    OptInStatusType,
    OrganizationResourceCollectionTypeType,
    ResourceCollectionTypeType,
    SearchInsightsPaginatorName,
    SearchOrganizationInsightsPaginatorName,
    ServiceNameType,
    UpdateResourceCollectionActionType,
    ServiceName,
    PaginatorName,
)

def check_value(value: AnomalySeverityType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_devops_guru.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_devops_guru.type_defs import (
    AccountHealthTypeDef,
    AccountInsightHealthTypeDef,
    AddNotificationChannelRequestRequestTypeDef,
    AddNotificationChannelResponseTypeDef,
    AnomalyReportedTimeRangeTypeDef,
    AnomalyResourceTypeDef,
    AnomalySourceDetailsTypeDef,
    AnomalyTimeRangeTypeDef,
    CloudFormationCollectionFilterTypeDef,
    CloudFormationCollectionTypeDef,
    CloudFormationCostEstimationResourceCollectionFilterTypeDef,
    CloudFormationHealthTypeDef,
    CloudWatchMetricsDataSummaryTypeDef,
    CloudWatchMetricsDetailTypeDef,
    CloudWatchMetricsDimensionTypeDef,
    CostEstimationResourceCollectionFilterTypeDef,
    CostEstimationTimeRangeTypeDef,
    DescribeAccountHealthResponseTypeDef,
    DescribeAccountOverviewRequestRequestTypeDef,
    DescribeAccountOverviewResponseTypeDef,
    DescribeAnomalyRequestRequestTypeDef,
    DescribeAnomalyResponseTypeDef,
    DescribeFeedbackRequestRequestTypeDef,
    DescribeFeedbackResponseTypeDef,
    DescribeInsightRequestRequestTypeDef,
    DescribeInsightResponseTypeDef,
    DescribeOrganizationHealthRequestRequestTypeDef,
    DescribeOrganizationHealthResponseTypeDef,
    DescribeOrganizationOverviewRequestRequestTypeDef,
    DescribeOrganizationOverviewResponseTypeDef,
    DescribeOrganizationResourceCollectionHealthRequestRequestTypeDef,
    DescribeOrganizationResourceCollectionHealthResponseTypeDef,
    DescribeResourceCollectionHealthRequestRequestTypeDef,
    DescribeResourceCollectionHealthResponseTypeDef,
    DescribeServiceIntegrationResponseTypeDef,
    EndTimeRangeTypeDef,
    EventResourceTypeDef,
    EventTimeRangeTypeDef,
    EventTypeDef,
    GetCostEstimationRequestRequestTypeDef,
    GetCostEstimationResponseTypeDef,
    GetResourceCollectionRequestRequestTypeDef,
    GetResourceCollectionResponseTypeDef,
    InsightFeedbackTypeDef,
    InsightHealthTypeDef,
    InsightTimeRangeTypeDef,
    ListAnomaliesForInsightRequestRequestTypeDef,
    ListAnomaliesForInsightResponseTypeDef,
    ListEventsFiltersTypeDef,
    ListEventsRequestRequestTypeDef,
    ListEventsResponseTypeDef,
    ListInsightsAnyStatusFilterTypeDef,
    ListInsightsClosedStatusFilterTypeDef,
    ListInsightsOngoingStatusFilterTypeDef,
    ListInsightsRequestRequestTypeDef,
    ListInsightsResponseTypeDef,
    ListInsightsStatusFilterTypeDef,
    ListNotificationChannelsRequestRequestTypeDef,
    ListNotificationChannelsResponseTypeDef,
    ListOrganizationInsightsRequestRequestTypeDef,
    ListOrganizationInsightsResponseTypeDef,
    ListRecommendationsRequestRequestTypeDef,
    ListRecommendationsResponseTypeDef,
    NotificationChannelConfigTypeDef,
    NotificationChannelTypeDef,
    OpsCenterIntegrationConfigTypeDef,
    OpsCenterIntegrationTypeDef,
    PaginatorConfigTypeDef,
    PerformanceInsightsMetricDimensionGroupTypeDef,
    PerformanceInsightsMetricQueryTypeDef,
    PerformanceInsightsMetricsDetailTypeDef,
    PerformanceInsightsReferenceComparisonValuesTypeDef,
    PerformanceInsightsReferenceDataTypeDef,
    PerformanceInsightsReferenceMetricTypeDef,
    PerformanceInsightsReferenceScalarTypeDef,
    PerformanceInsightsStatTypeDef,
    PredictionTimeRangeTypeDef,
    ProactiveAnomalySummaryTypeDef,
    ProactiveAnomalyTypeDef,
    ProactiveInsightSummaryTypeDef,
    ProactiveInsightTypeDef,
    ProactiveOrganizationInsightSummaryTypeDef,
    PutFeedbackRequestRequestTypeDef,
    ReactiveAnomalySummaryTypeDef,
    ReactiveAnomalyTypeDef,
    ReactiveInsightSummaryTypeDef,
    ReactiveInsightTypeDef,
    ReactiveOrganizationInsightSummaryTypeDef,
    RecommendationRelatedAnomalyResourceTypeDef,
    RecommendationRelatedAnomalySourceDetailTypeDef,
    RecommendationRelatedAnomalyTypeDef,
    RecommendationRelatedCloudWatchMetricsSourceDetailTypeDef,
    RecommendationRelatedEventResourceTypeDef,
    RecommendationRelatedEventTypeDef,
    RecommendationTypeDef,
    RemoveNotificationChannelRequestRequestTypeDef,
    ResourceCollectionFilterTypeDef,
    ResourceCollectionTypeDef,
    ResponseMetadataTypeDef,
    SearchInsightsFiltersTypeDef,
    SearchInsightsRequestRequestTypeDef,
    SearchInsightsResponseTypeDef,
    SearchOrganizationInsightsFiltersTypeDef,
    SearchOrganizationInsightsRequestRequestTypeDef,
    SearchOrganizationInsightsResponseTypeDef,
    ServiceCollectionTypeDef,
    ServiceHealthTypeDef,
    ServiceInsightHealthTypeDef,
    ServiceIntegrationConfigTypeDef,
    ServiceResourceCostTypeDef,
    SnsChannelConfigTypeDef,
    StartCostEstimationRequestRequestTypeDef,
    StartTimeRangeTypeDef,
    TagCollectionFilterTypeDef,
    TagCollectionTypeDef,
    TagCostEstimationResourceCollectionFilterTypeDef,
    TagHealthTypeDef,
    TimestampMetricValuePairTypeDef,
    UpdateCloudFormationCollectionFilterTypeDef,
    UpdateResourceCollectionFilterTypeDef,
    UpdateResourceCollectionRequestRequestTypeDef,
    UpdateServiceIntegrationConfigTypeDef,
    UpdateServiceIntegrationRequestRequestTypeDef,
    UpdateTagCollectionFilterTypeDef,
)

def get_structure() -> AccountHealthTypeDef:
    return {
      ...
    }
```

## Versioning

`types-aiobotocore-devops-guru` version is the same as related `boto3` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation

All type annotations can be found in
[types-aiobotocore-devops-guru docs](https://vemel.github.io/types_aiobotocore_docs/types_aiobotocore_devops_guru/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
